@@ -837,7 +837,7 @@ void get_dirac_cdata(lives_clip_data_t *cdata, SchroDecoder *schrodec) {
  cdata->frame_height=sformat->height;
 
  cdata->width=sformat->clean_width;
- cdata->height=sformat->clean_height;
+ cdata->height=(sformat->clean_height>>1)<<1;
  
 
  if (sformat->interlaced) {
@@ -2405,10 +2405,6 @@ static boolean ogg_data_process(lives_clip_data_t *cdata, void *yuvbuffer, boole
 #ifdef HAVE_THEORA
       if (priv->vstream->stpriv->fourcc_priv==FOURCC_THEORA) {
 	
-	if (priv->cframe==priv->last_kframe) {
-	  priv->ignore_packets=FALSE; // reached kframe before target, start decoding packets
-	}
-	
 	if (!priv->ignore_packets) {
 	  yuv_buffer *yuv=yuvbuffer;
 	  ogg_theora_read(cdata,&opriv->op,yuv);
@@ -2439,6 +2435,7 @@ static boolean ogg_data_process(lives_clip_data_t *cdata, void *yuvbuffer, boole
       
       sched_yield();
     }
+    priv->ignore_packets=FALSE; // start decoding packets
 
     cont=FALSE;
   }
@@ -2447,7 +2444,7 @@ static boolean ogg_data_process(lives_clip_data_t *cdata, void *yuvbuffer, boole
 }
 
 
-boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, void **pixel_data) {
+boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int* rowstrides, int height, void **pixel_data) {
   // seek to frame, and return pixel_data
 
   lives_ogg_priv_t *priv=(lives_ogg_priv_t *)cdata->priv;
@@ -2556,7 +2553,8 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, void **pixel_d
     
     //printf("cf %ld and %ld\n",tframe,priv->last_frame);
 
-    if (tframe>priv->last_frame&&(tframe-priv->last_frame<=max_frame_diff||(kframe==priv->last_kframe&&priv->vstream->stpriv->fourcc_priv==FOURCC_THEORA))) {
+    if (tframe>priv->last_frame&&(tframe-priv->last_frame<=max_frame_diff||
+				  (kframe==priv->last_kframe&&priv->vstream->stpriv->fourcc_priv==FOURCC_THEORA))) {
       // same keyframe as last time, or next frame; we can continue where we left off
       cont=TRUE;
       priv->skip=tframe-priv->last_frame-1;
@@ -2571,15 +2569,24 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, void **pixel_d
 	  //fprintf(stderr,"starting from found gpos %ld\n",granulepos);
 	
 	  xkframe=granulepos >> priv->vstream->stpriv->keyframe_granule_shift;
+
+
+	  get_bounds_for((lives_clip_data_t *)cdata,xkframe-1,&ppos_lower,&ppos_upper);
+	  granulepos=ogg_seek((lives_clip_data_t *)cdata,xkframe-1,ppos_lower,ppos_upper,FALSE);
+	  //fprintf(stderr,"starting from found gpos %ld\n",granulepos);
+	
+	  xkframe=granulepos >> priv->vstream->stpriv->keyframe_granule_shift;
+
+
+
 	  priv->cframe = xkframe + granulepos-(xkframe<<priv->vstream->stpriv->keyframe_granule_shift); // cframe will be the next frame we decode
 	  //printf("xkframe is %ld %ld\n",xkframe,priv->cframe);
 	}
 	else {
 	  priv->cframe=kframe;
 	  priv->input_position=priv->cpagepos;
-	  //printf("SEEK TO %ld\n",priv->cpagepos);
+	  printf("SEEK TO %ld\n",priv->cpagepos);
 	}
-	//1671
 
 	if (priv->input_position==priv->vstream->data_start) {
 	  priv->cframe=kframe=priv->kframe_offset;
@@ -2631,13 +2638,13 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, void **pixel_d
     
     for (i=0;i<mheight;i++) {
       memcpy(pixel_data[0],y,opriv->y_width);
-      pixel_data[0]+=opriv->y_width;
+      pixel_data[0]+=rowstrides[0];
       y+=yuv.y_stride;
       if (yuv.y_height==yuv.uv_height||crow) {
 	memcpy(pixel_data[1],u,opriv->uv_width);
 	memcpy(pixel_data[2],v,opriv->uv_width);
-	pixel_data[1]+=opriv->uv_width;
-	pixel_data[2]+=opriv->uv_width;
+	pixel_data[1]+=rowstrides[1];
+	pixel_data[2]+=rowstrides[2];
 	u+=yuv.uv_stride;
 	v+=yuv.uv_stride;
       }
