@@ -9,7 +9,7 @@
 
 /////////////////////////////////////////////////////////////////
 
-static char plugin_version[64]="LiVES vloopback output client 1.0.1";
+static char plugin_version[64]="LiVES vloopback output client 1.0.2";
 static int palette_list[3];
 static int clampings[2];
 static int mypalette;
@@ -22,7 +22,15 @@ static int mypalette;
 #include <fcntl.h>
 #include <dirent.h>
 #include <unistd.h>
+
+#if v4l1_INCFILE == 2
+#include <libv4l1-videodev.h>
+#else
+#if v4l1_INCFILE == 1
 #include <linux/videodev.h>
+#endif
+#endif
+
 #include <sys/ioctl.h>
 
 static struct video_window x_vidwin;
@@ -88,7 +96,7 @@ static char **get_vloopback_devices(void) {
    n = scandir( "/dev", &namelist, file_filter, alphasort );
    if( n < 0 ) return devnames;
    
-   
+    
    for(i=0; i < n && ndevices < MAX_DEVICES-1; i++ ) {
      sprintf( devname, "/dev/%s", namelist[i]->d_name );
 
@@ -161,6 +169,7 @@ const char rfx[32768];
 const char *get_rfx (void) {
   char **vdevs = get_vloopback_devices();
   char devstr[30000];
+  size_t slen=0;
   int i=0;
 
   if (vdevs[0]==NULL) {
@@ -171,7 +180,8 @@ const char *get_rfx (void) {
   memset( devstr, 0, 1 );
 
   while (vdevs[i]!=NULL) {
-    snprintf(devstr,30000,"%s%s|",devstr,vdevs[i]);
+    snprintf(devstr+slen,30000-slen,"%s|",vdevs[i]);
+    slen+=strlen(vdevs[i])+1;
     free(vdevs[i++]);
   }
   free( vdevs );
@@ -200,7 +210,7 @@ vdevname|Video _device|string_list|0|",
 }
 
 
-int *get_palette_list(void) {
+const int *get_palette_list(void) {
   palette_list[0]=WEED_PALETTE_UYVY;
   palette_list[1]=WEED_PALETTE_RGB24;
   palette_list[2]=WEED_PALETTE_END;
@@ -220,7 +230,7 @@ boolean set_palette (int palette) {
   return FALSE;
 }
 
-int *get_yuv_palette_clamping(int palette) {
+const int *get_yuv_palette_clamping(int palette) {
   if (palette==WEED_PALETTE_RGB24) clampings[0]=-1;
   else {
     clampings[0]=WEED_YUV_CLAMPING_CLAMPED;
