@@ -646,8 +646,7 @@ void
 on_showfct_activate               (GtkMenuItem     *menuitem,
 				   gpointer         user_data);
 
-void on_boolean_toggled  (GtkMenuItem     *menuitem,
-			  gpointer         user_data);
+void on_boolean_toggled(GtkObject *, gpointer user_data);
 
 void
 on_show_messages_activate            (GtkMenuItem     *menuitem,
@@ -768,3 +767,6 @@ void on_lerrors_close_clicked (GtkButton *, gpointer);
 void on_lerrors_clear_clicked (GtkButton *, gpointer);
 void on_lerrors_delete_clicked (GtkButton *, gpointer);
 
+void drag_from_outside(GtkWidget *widget, GdkDragContext *dcon, gint x, gint y, 
+		       GtkSelectionData *data, guint info, guint time, gpointer user_data);
+
