@@ -1840,10 +1840,10 @@ gboolean switch_aud_to_pulse(void) {
 
 
 
-void switch_aud_to_sox(void) {
+void switch_aud_to_sox(gboolean set_in_prefs) {
   prefs->audio_player=AUD_PLAYER_SOX;
   get_pref_default("sox_command",prefs->audio_play_command,256);
-  set_pref("audio_player","sox");
+  if (set_in_prefs) set_pref("audio_player","sox");
   g_snprintf(prefs->aplayer,512,"%s","sox");
   set_pref("audio_play_command",prefs->audio_play_command);
   if (mainw->is_ready) {
@@ -1885,7 +1885,7 @@ void switch_aud_to_sox(void) {
 
 
 void
-switch_aud_to_mplayer(void) {
+switch_aud_to_mplayer(gboolean set_in_prefs) {
   int i;
   for (i=1;i<MAX_FILES;i++) {
     if (mainw->files[i]!=NULL) {
@@ -1898,7 +1898,7 @@ switch_aud_to_mplayer(void) {
   
   prefs->audio_player=AUD_PLAYER_MPLAYER;
   get_pref_default("mplayer_audio_command",prefs->audio_play_command,256);
-  set_pref("audio_player","mplayer");
+  if (set_in_prefs) set_pref("audio_player","mplayer");
   g_snprintf(prefs->aplayer,512,"%s","mplayer");
   set_pref("audio_play_command",prefs->audio_play_command);
   if (mainw->is_ready) {
@@ -3502,3 +3502,70 @@ LIVES_INLINE GList *g_list_move_to_first(GList *list, GList *item) {
 }
 
 
+GList *g_list_delete_string(GList *list, char *string) {
+  // remove string from list, using strcmp
+
+  GList *xlist=list;
+  while (xlist!=NULL) {
+    if (!strcmp((char *)xlist->data,string)) {
+      if (xlist->prev!=NULL) xlist->prev->next=xlist->next;
+      else list=xlist->next;
+      if (xlist->next!=NULL) xlist->next->prev=xlist->prev;
+      xlist->next=xlist->prev=NULL;
+      g_free(xlist->data);
+      g_list_free(xlist);
+      return list;
+    }
+    xlist=xlist->next;
+  }
+  return list;
+}
+
+
+GList *g_list_copy_strings(GList *list) {
+  // copy a list, copying the strings too
+
+  GList *xlist=NULL,*olist=list;
+
+  while (olist!=NULL) {
+    xlist=g_list_append(xlist,g_strdup((gchar *)olist->data));
+    olist=olist->next;
+  }
+
+  return xlist;
+}
+
+
+
+
+gboolean string_lists_differ(GList *alist, GList *blist) {
+  // compare 2 lists of strings and see if they are different (ignoring ordering)
+  // for long lists this would be quicker if we sorted the lists first; however this function 
+  // is designed to deal with short lists only
+
+
+  GList *plist;
+
+  if (g_list_length(alist)!=g_list_length(blist)) return TRUE; // check the simple case first
+
+  // run through alist and see if we have a mismatch
+
+  plist=alist;
+  while (plist!=NULL) {
+    GList *qlist=blist;
+    gboolean matched=FALSE;
+    while (qlist!=NULL) {
+      if (!(strcmp((char *)plist->data,(char *)qlist->data))) {
+	matched=TRUE;
+	break;
+      }
+      qlist=qlist->next;
+    }
+    if (!matched) return TRUE;
+    plist=plist->next;
+  }
+
+  // since both lists were of the same length, there is no need to check blist
+
+  return FALSE;
+}
